@@ -17,6 +17,7 @@ from uuid import uuid4
 import six
 
 from ncclient.xml_ import *
+from ncclient.logging_ import SessionLoggerAdapter
 from ncclient.transport import SessionListener
 
 from ncclient.operations.errors import OperationError, TimeoutExpiredError, MissingCapabilityError
@@ -164,6 +165,7 @@ class RPCReply(object):
     @property
     def ok(self):
         "Boolean value indicating if there were no errors."
+        self.parse()
         return not self.errors # empty list => false
 
     @property
@@ -197,6 +199,8 @@ class RPCReplyListener(SessionListener): # internal use
                 instance._device_handler = device_handler
                 #instance._pipelined = session.can_pipeline
                 session.add_listener(instance)
+                instance.logger = SessionLoggerAdapter(logger,
+                                                       {'session': session})
             return instance
 
     def register(self, id, rpc):
@@ -216,7 +220,7 @@ class RPCReplyListener(SessionListener): # internal use
             with self._lock:
                 try:
                     rpc = self._id2rpc[id]  # the corresponding rpc
-                    logger.debug("Delivering to %r" % rpc)
+                    self.logger.debug("Delivering to %r", rpc)
                     rpc.deliver_reply(raw)
                 except KeyError:
                     raise OperationError("Unknown 'message-id': %s" % id)
@@ -291,6 +295,7 @@ class RPC(object):
         self._error = None
         self._event = Event()
         self._device_handler = device_handler
+        self.logger = SessionLoggerAdapter(logger, {'session': session})
 
 
     def _wrap(self, subele):
@@ -310,14 +315,14 @@ class RPC(object):
 
         *op* is the operation to be requested as an :class:`~xml.etree.ElementTree.Element`
         """
-        logger.info('Requesting %r' % self.__class__.__name__)
+        self.logger.info('Requesting %r', self.__class__.__name__)
         req = self._wrap(op)
         self._session.send(req)
         if self._async:
-            logger.debug('Async request, returning %r', self)
+            self.logger.debug('Async request, returning %r', self)
             return self
         else:
-            logger.debug('Sync request, will wait for timeout=%r' % self._timeout)
+            self.logger.debug('Sync request, will wait for timeout=%r', self._timeout)
             self._event.wait(self._timeout)
             if self._event.isSet():
                 if self._error:
